//@line 36 "/builds/slave/release-mozilla-1.9.2-linux_repack_3/build/l10n-mozilla-1.9.2/ka/browser/firefox-l10n.js"

//@line 38 "/builds/slave/release-mozilla-1.9.2-linux_repack_3/build/l10n-mozilla-1.9.2/ka/browser/firefox-l10n.js"

pref("general.useragent.locale", "ka");
